# Package Name

Package function description

## Installation

`pip install autoscirpt`

## How to use it?

Function of the package

## License

copyright @ 2021 BDFD

This repository is licensed under the MIT license. See LICENSE for details.

### References

https://github.com/bdfd/Section5.4-Python-Automation-Script
